pub struct RangeFull;Expand description
An unbounded range (..).
RangeFull is primarily used as a slicing index, its shorthand is ...
It cannot serve as an Iterator because it doesn’t have a starting point.
Examples
The .. syntax is a RangeFull:
assert_eq!(.., std::ops::RangeFull);It does not have an IntoIterator implementation, so you can’t use it in
a for loop directly. This won’t compile:
for i in .. {
// ...
}Used as a slicing index, RangeFull produces the full array as a slice.
let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ .. ], [0, 1, 2, 3, 4]); // This is the `RangeFull`
assert_eq!(arr[ .. 3], [0, 1, 2 ]);
assert_eq!(arr[ ..=3], [0, 1, 2, 3 ]);
assert_eq!(arr[1.. ], [ 1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [ 1, 2 ]);
assert_eq!(arr[1..=3], [ 1, 2, 3 ]);Trait Implementations
sourceimpl Archive for RangeFull
impl Archive for RangeFull
sourceimpl<'a, T, O> BitSliceIndex<'a, T, O> for RangeFull
impl<'a, T, O> BitSliceIndex<'a, T, O> for RangeFull
sourcefn get(
self,
bits: <RangeFull as BitSliceIndex<'a, T, O>>::Immut,
) -> Option<<RangeFull as BitSliceIndex<'a, T, O>>::Immut>
fn get( self, bits: <RangeFull as BitSliceIndex<'a, T, O>>::Immut, ) -> Option<<RangeFull as BitSliceIndex<'a, T, O>>::Immut>
sourcefn get_mut(
self,
bits: <RangeFull as BitSliceIndex<'a, T, O>>::Mut,
) -> Option<<RangeFull as BitSliceIndex<'a, T, O>>::Mut>
fn get_mut( self, bits: <RangeFull as BitSliceIndex<'a, T, O>>::Mut, ) -> Option<<RangeFull as BitSliceIndex<'a, T, O>>::Mut>
sourceunsafe fn get_unchecked(
self,
bits: <RangeFull as BitSliceIndex<'a, T, O>>::Immut,
) -> <RangeFull as BitSliceIndex<'a, T, O>>::Immut
unsafe fn get_unchecked( self, bits: <RangeFull as BitSliceIndex<'a, T, O>>::Immut, ) -> <RangeFull as BitSliceIndex<'a, T, O>>::Immut
sourceunsafe fn get_unchecked_mut(
self,
bits: <RangeFull as BitSliceIndex<'a, T, O>>::Mut,
) -> <RangeFull as BitSliceIndex<'a, T, O>>::Mut
unsafe fn get_unchecked_mut( self, bits: <RangeFull as BitSliceIndex<'a, T, O>>::Mut, ) -> <RangeFull as BitSliceIndex<'a, T, O>>::Mut
sourcefn index(
self,
bits: <RangeFull as BitSliceIndex<'a, T, O>>::Immut,
) -> <RangeFull as BitSliceIndex<'a, T, O>>::Immut
fn index( self, bits: <RangeFull as BitSliceIndex<'a, T, O>>::Immut, ) -> <RangeFull as BitSliceIndex<'a, T, O>>::Immut
self is out of
bounds. Read moresourcefn index_mut(
self,
bits: <RangeFull as BitSliceIndex<'a, T, O>>::Mut,
) -> <RangeFull as BitSliceIndex<'a, T, O>>::Mut
fn index_mut( self, bits: <RangeFull as BitSliceIndex<'a, T, O>>::Mut, ) -> <RangeFull as BitSliceIndex<'a, T, O>>::Mut
self is out of bounds. Read moresourceimpl<C1> ContainsToken<C1> for RangeFullwhere
C1: AsChar,
impl<C1> ContainsToken<C1> for RangeFullwhere
C1: AsChar,
sourcefn contains_token(&self, _token: C1) -> bool
fn contains_token(&self, _token: C1) -> bool
sourceimpl<D> Deserialize<RangeFull, D> for RangeFull
impl<D> Deserialize<RangeFull, D> for RangeFull
sourceimpl<T> From<RangeFull> for IntervalIterator<T>
impl<T> From<RangeFull> for IntervalIterator<T>
sourceimpl Index<RangeFull> for ArchivedCString
impl Index<RangeFull> for ArchivedCString
sourceimpl Index<RangeFull> for ArchivedString
impl Index<RangeFull> for ArchivedString
sourceimpl Index<RangeFull> for RecoverableSignature
impl Index<RangeFull> for RecoverableSignature
sourceimpl Index<RangeFull> for UninitSlice
impl Index<RangeFull> for UninitSlice
type Output = UninitSlice
type Output = UninitSlice
sourceimpl Index<RangeFull> for XOnlyPublicKey
impl Index<RangeFull> for XOnlyPublicKey
sourceimpl IndexMut<RangeFull> for UninitSlice
impl IndexMut<RangeFull> for UninitSlice
1.0.0 · sourceimpl PartialEq for RangeFull
impl PartialEq for RangeFull
1.28.0 · sourceimpl<T> RangeBounds<T> for RangeFullwhere
T: ?Sized,
impl<T> RangeBounds<T> for RangeFullwhere
T: ?Sized,
1.15.0 (const: unstable) · sourceimpl<T> SliceIndex<[T]> for RangeFull
impl<T> SliceIndex<[T]> for RangeFull
sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)slice pointer
is undefined behavior even if the resulting pointer is not used.sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)slice pointer
is undefined behavior even if the resulting pointer is not used.1.20.0 (const: unstable) · sourceimpl SliceIndex<str> for RangeFull
impl SliceIndex<str> for RangeFull
Implements substring slicing with syntax &self[..] or &mut self[..].
Returns a slice of the whole string, i.e., returns &self or &mut self. Equivalent to &self[0 .. len] or &mut self[0 .. len]. Unlike
other indexing operations, this can never panic.
This operation is O(1).
Prior to 1.20.0, these indexing operations were still supported by
direct implementation of Index and IndexMut.
Equivalent to &self[0 .. len] or &mut self[0 .. len].
sourcefn get(self, slice: &str) -> Option<&<RangeFull as SliceIndex<str>>::Output>
fn get(self, slice: &str) -> Option<&<RangeFull as SliceIndex<str>>::Output>
slice_index_methods)sourcefn get_mut(
self,
slice: &mut str,
) -> Option<&mut <RangeFull as SliceIndex<str>>::Output>
fn get_mut( self, slice: &mut str, ) -> Option<&mut <RangeFull as SliceIndex<str>>::Output>
slice_index_methods)sourceunsafe fn get_unchecked(
self,
slice: *const str,
) -> *const <RangeFull as SliceIndex<str>>::Output
unsafe fn get_unchecked( self, slice: *const str, ) -> *const <RangeFull as SliceIndex<str>>::Output
slice_index_methods)slice pointer
is undefined behavior even if the resulting pointer is not used.sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str,
) -> *mut <RangeFull as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut str, ) -> *mut <RangeFull as SliceIndex<str>>::Output
slice_index_methods)slice pointer
is undefined behavior even if the resulting pointer is not used.impl Copy for RangeFull
impl Eq for RangeFull
impl StructuralPartialEq for RangeFull